@@ -17,6 +17,25 @@
  *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
+/**
+ * @defgroup libteam Libteam
+ * Low-level team netlink wrapper library
+ *
+ * @{
+ *
+ * @ingroup libteam
+ * @defgroup core Libteam core funtions
+ * Libteam core funtions
+ *
+ * @{
+ *
+ * Header
+ * ------
+ * ~~~~{.c}
+ * #include <team.h>
+ * ~~~~
+ */
+
 #include <stdint.h>
 #include <stdbool.h>
 #include <stdlib.h>
@@ -39,10 +58,8 @@
 #include <private/misc.h>
 #include "team_private.h"
 
-/**
- * SECTION: logging
- * @short_description: libteam logging facility
- */
+/* \cond HIDDEN_SYMBOLS */
+
 void team_log(struct team_handle *th, int priority,
 	      const char *file, int line, const char *fn,
 	      const char *format, ...)
@@ -82,7 +99,6 @@ static int log_priority(const char *priority)
 
 /**
  * SECTION: libnl helpers
- * @short_description: various libnl helper functions
  */
 
 int nl2syserr(int nl_error)
@@ -111,7 +127,6 @@ int nl2syserr(int nl_error)
 
 /**
  * SECTION: Netlink helpers
- * @short_description: Various netlink helpers
  */
 
 static int ack_handler(struct nl_msg *msg, void *arg)
@@ -186,7 +201,6 @@ put_cb:
 
 /**
  * SECTION: Change handlers
- * @short_description: event change handlers handling
  */
 
 struct change_handler_item {
@@ -261,17 +275,18 @@ __team_change_handler_register(struct team_handle *th,
 	return 0;
 }
 
+/* \endcond */
+
 /**
- * team_change_handler_register:
- * @th: libteam library context
- * @handler: event handler structure
- * @priv: event handler func private data
+ * @param th		libteam library context
+ * @param handler	event handler structure
+ * @param priv		event handler func private data
  *
- * Registers custom @handler structure which defines a function which
- * going to be called on defined events. The handler will be added
- * at the end of the list.
+ * @details Registers custom handler structure which defines a function which
+ *	    going to be called on defined events. The handler will be added
+ *	    at the end of the list.
  *
- * Returns: zero on success or negative number in case of an error.
+ * @return Zero on success or negative number in case of an error.
  **/
 TEAM_EXPORT
 int team_change_handler_register(struct team_handle *th,
@@ -282,16 +297,15 @@ int team_change_handler_register(struct team_handle *th,
 }
 
 /**
- * team_change_handler_register_head:
- * @th: libteam library context
- * @handler: event handler structure
- * @priv: event handler func private data
+ * @param th		libteam library context
+ * @param handler	event handler structure
+ * @param priv		event handler func private data
  *
- * Registers custom @handler structure which defines a function which
- * going to be called on defined events. The handler will be added
- * at the start of the list.
+ * @details Registers custom handler structure which defines a function which
+ *	    going to be called on defined events. The handler will be added
+ *	    at the start of the list.
  *
- * Returns: zero on success or negative number in case of an error.
+ * @return Zero on success or negative number in case of an error.
  **/
 TEAM_EXPORT
 int team_change_handler_register_head(struct team_handle *th,
@@ -303,13 +317,11 @@ int team_change_handler_register_head(struct team_handle *th,
 
 
 /**
- * team_change_handler_unregister:
- * @th: libteam library context
- * @handler: event handler structure
- * @priv: event handler func private data
- *
- * Unregisters custom @handler structure.
+ * @param th		libteam library context
+ * @param handler	event handler structure
+ * @param priv		event handler func private data
  *
+ * @details Unregisters custom handler structure.
  **/
 TEAM_EXPORT
 void team_change_handler_unregister(struct team_handle *th,
@@ -327,7 +339,6 @@ void team_change_handler_unregister(struct team_handle *th,
 
 /**
  * SECTION: Context functions
- * @short_description: Core context functions
  */
 
 static int event_handler(struct nl_msg *msg, void *arg)
@@ -351,11 +362,10 @@ static int cli_event_handler(struct nl_msg *msg, void *arg)
 static int team_init_event_fd(struct team_handle *th);
 
 /**
- * team_alloc:
+ * @details Allocates library context, sockets, initializes rtnl
+ *	    netlink connection.
  *
- * Allocates library context, sockets, initializes rtnl netlink connection.
- *
- * Returns: new libteam library context
+ * @return New libteam library context.
  **/
 TEAM_EXPORT
 struct team_handle *team_alloc(void)
@@ -470,14 +480,13 @@ errout:
 }
 
 /**
- * team_create:
- * @th: libteam library context
- * @team_name: new team device name
+ * @param th		libteam library context
+ * @param team_name	new team device name
  *
- * Create new team device by given name. If NULL is passed, name will be
- * allocated automatically.
+ * @details Create new team device by given name. If NULL is passed, name
+ *	    will be allocated automatically.
  *
- * Returns: zero on success or negative number in case of an error.
+ * @return Zero on success or negative number in case of an error.
  **/
 TEAM_EXPORT
 int team_create(struct team_handle *th, const char *team_name)
@@ -486,14 +495,13 @@ int team_create(struct team_handle *th, const char *team_name)
 }
 
 /**
- * team_recreate:
- * @th: libteam library context
- * @team_name: new team device name
+ * @param th		libteam library context
+ * @param team_name	new team device name
  *
- * Does the same as team_create only if device with @team_name already
- * exists it will be deleted first.
+ * @details Does the same as team_create only if device with team_name already
+ *	    exists it will be deleted first.
  *
- * Returns: zero on success or negative number in case of an error.
+ * @return Zero on success or negative number in case of an error.
  **/
 TEAM_EXPORT
 int team_recreate(struct team_handle *th, const char *team_name)
@@ -502,12 +510,11 @@ int team_recreate(struct team_handle *th, const char *team_name)
 }
 
 /**
- * team_destroy:
- * @th: libteam library context
+ * @param th		libteam library context
  *
- * Destroys current initialized team device.
+ * @details Destroy current initialized team device.
  *
- * Returns: zero on success or negative number in case of an error.
+ * @return Zero on success or negative number in case of an error.
  **/
 TEAM_EXPORT
 int team_destroy(struct team_handle *th)
@@ -526,6 +533,7 @@ int team_destroy(struct team_handle *th)
 	return -nl2syserr(err);
 }
 
+/* \cond HIDDEN_SYMBOLS */
 #ifndef SOL_NETLINK
 #define SOL_NETLINK 270
 #endif
@@ -533,15 +541,16 @@ int team_destroy(struct team_handle *th)
 #ifndef NETLINK_BROADCAST_SEND_ERROR
 #define NETLINK_BROADCAST_SEND_ERROR    0x4
 #endif
+/* \endcond */
 
 /**
- * team_init:
- * @th: libteam library context
- * @ifindex: team device interface index
+ * @param th		libteam library context
+ * @param ifindex	team device interface index
  *
- * Do library context initialization. Sets up team generic netlink connection.
+ * @details Do library context initialization. Sets up team generic
+ *	    netlink connection.
  *
- * Returns: zero on success or negative number in case of an error.
+ * @return Zero on success or negative number in case of an error.
  **/
 TEAM_EXPORT
 int team_init(struct team_handle *th, uint32_t ifindex)
@@ -655,11 +664,9 @@ int team_init(struct team_handle *th, uint32_t ifindex)
 }
 
 /**
- * team_free:
- * @th: libteam library context
- *
- * Do library context cleanup.
+ * @param th		libteam library context
  *
+ * @details Do library context cleanup.
  **/
 TEAM_EXPORT
 void team_free(struct team_handle *th)
@@ -676,12 +683,12 @@ void team_free(struct team_handle *th)
 }
 
 /**
- * team_refresh:
- * @th: libteam library context
+ * @param th		libteam library context
  *
- * This is used for user to refresh internal lists and call event handlers.
+ * @details This is used for user to refresh internal lists and call
+ *	    event handlers.
  *
- * Returns: zero on success or negative number in case of an error.
+ * @return Zero on success or negative number in case of an error.
  **/
 TEAM_EXPORT
 int team_refresh(struct team_handle *th)
@@ -709,14 +716,12 @@ int team_refresh(struct team_handle *th)
 }
 
 /**
- * team_set_log_fn:
- * @th: libteam library context
- * @log_fn: function to be called for logging messages
- *
- * The built-in logging writes to stderr. It can be
- * overridden by a custom function, to plug log messages
- * into the user's logging functionality.
+ * @param th		libteam library context
+ * @param log_fn	function to be called for logging messages
  *
+ * @details The built-in logging writes to stderr. It can be overridden
+ *	    by a custom function, to plug log messages into the user's
+ *	    logging functionality.
  **/
 TEAM_EXPORT
 void team_set_log_fn(struct team_handle *th,
@@ -729,10 +734,9 @@ void team_set_log_fn(struct team_handle *th,
 }
 
 /**
- * team_get_log_priority:
- * @th: libteam library context
+ * @param th		libteam library context
  *
- * Returns: the current logging priority
+ * @return The current logging priority.
  **/
 TEAM_EXPORT
 int team_get_log_priority(struct team_handle *th)
@@ -741,12 +745,11 @@ int team_get_log_priority(struct team_handle *th)
 }
 
 /**
- * team_set_log_priority:
- * @th: libteam library context
- * @priority: the new logging priority
+ * @param th		libteam library context
+ * @param priority	the new logging priority
  *
- * Set the current logging priority. The value controls which messages
- * are logged.
+ * @details Set the current logging priority. The value controls which messages
+ *	    are logged.
  **/
 TEAM_EXPORT
 void team_set_log_priority(struct team_handle *th, int priority)
@@ -784,10 +787,12 @@ static int sock_event_handler(struct team_handle *th)
 					      TEAM_IFINFO_CHANGE);
 }
 
+/* \cond HIDDEN_SYMBOLS */
 struct team_eventfd {
 	int (*get_fd)(struct team_handle *th);
 	int (*event_handler)(struct team_handle *th);
 };
+/* \endcond */
 
 static const struct team_eventfd team_eventfds[] = {
 	/* Always handle cli socket first. The reason is that cli socket
@@ -803,18 +808,20 @@ static const struct team_eventfd team_eventfds[] = {
 		.event_handler = sock_event_handler,
 	},
 };
+
+/* \cond HIDDEN_SYMBOLS */
 #define TEAM_EVENT_FDS_COUNT ARRAY_SIZE(team_eventfds)
+/* \endcond */
 
 static const struct team_eventfd __dummy_eventfd;
 
 /**
- * team_get_next_eventfd:
- * @th: libteam library context
- * @eventfd: eventfd structure
+ * @param th		libteam library context
+ * @param eventfd	eventfd structure
  *
- * Get next eventfd in list.
+ * @details Get next eventfd in list.
  *
- * Returns: eventfd next to @eventfd passed.
+ * @return eventfd next to eventfd passed.
  *
  * @deprecated Use of this function is deprecated.
  **/
@@ -828,13 +835,12 @@ const struct team_eventfd *team_get_next_eventfd(struct team_handle *th,
 }
 
 /**
- * team_get_eventfd_fd:
- * @th: libteam library context
- * @eventfd: eventfd structure
+ * @param th		libteam library context
+ * @param eventfd	eventfd structure
  *
- * Get eventfd filedesctiptor.
+ * @details Get eventfd filedesctiptor.
  *
- * Returns: fd.
+ * @return fd.
  *
  * @deprecated Use of this function is deprecated. User should use
  *	       team_get_event_fd() funstion instead.
@@ -847,13 +853,12 @@ int team_get_eventfd_fd(struct team_handle *th,
 }
 
 /**
- * team_call_eventfd_handler:
- * @th: libteam library context
- * @eventfd: eventfd structure
+ * @param th		libteam library context
+ * @param eventfd	eventfd structure
  *
- * Call eventfd handler.
+ * @details Call eventfd handler.
  *
- * Returns: zero on success or negative number in case of an error.
+ * @return Zero on success or negative number in case of an error.
  *
  * @deprecated Use of this function is deprecated. User should use
  *	       team_handle_events() funstion instead.
@@ -895,12 +900,11 @@ close_efd:
 }
 
 /**
- * team_get_event_fd:
- * @th: libteam library context
+ * @param th		libteam library context
  *
- * Get event filedesctiptor.
+ * @details Get event filedesctiptor.
  *
- * Returns: fd.
+ * @return fd.
  **/
 TEAM_EXPORT
 int team_get_event_fd(struct team_handle *th)
@@ -909,13 +913,11 @@ int team_get_event_fd(struct team_handle *th)
 }
 
 /**
- * team_handle_events:
- * @th: libteam library context
- * @eventfd: eventfd structure
+ * @param th		libteam library context
  *
- * Handler events which happened on event filedescriptor.
+ * @details Handler events which happened on event filedescriptor.
  *
- * Returns: zero on success or negative number in case of an error.
+ * @return Zero on success or negative number in case of an error.
  **/
 TEAM_EXPORT
 int team_handle_events(struct team_handle *th)
@@ -946,14 +948,13 @@ int team_handle_events(struct team_handle *th)
 }
 
 /**
- * team_check_events:
- * @th: libteam library context
+ * @param th		libteam library context
  *
- * Check for events pending to be processed on event socket and process
- * them one by one. This is safe to be called even if no data present
- * on event socket file descriptor.
+ * @details Check for events pending to be processed on event socket and process
+ *	    them one by one. This is safe to be called even if no data present
+ *	    on event socket file descriptor.
  *
- * Returns: zero on success or negative number in case of an error.
+ * @return Zero on success or negative number in case of an error.
  **/
 TEAM_EXPORT
 int team_check_events(struct team_handle *th)
@@ -975,13 +976,12 @@ int team_check_events(struct team_handle *th)
 }
 
 /**
- * team_get_mode_name:
- * @th: libteam library context
- * @mode_name: where the mode name will be stored
+ * @param th		libteam library context
+ * @param mode_name	where the mode name will be stored
  *
- * Get name of currect mode.
+ * @details Get name of currect mode.
  *
- * Returns: zero on success or negative number in case of an error.
+ * @return Zero on success or negative number in case of an error.
  **/
 TEAM_EXPORT
 int team_get_mode_name(struct team_handle *th, char **mode_name)
@@ -996,13 +996,12 @@ int team_get_mode_name(struct team_handle *th, char **mode_name)
 }
 
 /**
- * team_set_mode_name:
- * @th: libteam library context
- * @mode_name: name of mode to be set
+ * @param th		libteam library context
+ * @param mode_name	name of mode to be set
  *
- * Set team mode.
+ * @details Set team mode.
  *
- * Returns: zero on success or negative number in case of an error.
+ * @return Zero on success or negative number in case of an error.
  **/
 TEAM_EXPORT
 int team_set_mode_name(struct team_handle *th, const char *mode_name)
@@ -1016,13 +1015,12 @@ int team_set_mode_name(struct team_handle *th, const char *mode_name)
 }
 
 /**
- * team_get_notify_peers_count:
- * @th: libteam library context
- * @count: where the count will be stored
+ * @param th		libteam library context
+ * @param count		where the count will be stored
  *
- * Get number of bursts of NAs and ARPs notifications sent to peers.
+ * @details Get number of bursts of NAs and ARPs notifications sent to peers.
  *
- * Returns: zero on success or negative number in case of an error.
+ * @return Zero on success or negative number in case of an error.
  **/
 TEAM_EXPORT
 int team_get_notify_peers_count(struct team_handle *th, uint32_t *count)
@@ -1037,13 +1035,12 @@ int team_get_notify_peers_count(struct team_handle *th, uint32_t *count)
 }
 
 /**
- * team_set_notify_peers_count:
- * @th: libteam library context
- * @count: number of bursts
+ * @param th		libteam library context
+ * @param count		number of bursts
  *
- * Set number of bursts of NAs and ARPs notifications sent to peers.
+ * @details Set number of bursts of NAs and ARPs notifications sent to peers.
  *
- * Returns: zero on success or negative number in case of an error.
+ * @return Zero on success or negative number in case of an error.
  **/
 TEAM_EXPORT
 int team_set_notify_peers_count(struct team_handle *th, uint32_t count)
@@ -1057,14 +1054,13 @@ int team_set_notify_peers_count(struct team_handle *th, uint32_t count)
 }
 
 /**
- * team_get_notify_peers_interval:
- * @th: libteam library context
- * @interval: where the interval will be stored
+ * @param th		libteam library context
+ * @param interval	where the interval will be stored
  *
- * Get interval (in milliseconds) in which bursts of NAs and ARPs notifications
- * are sent to peers.
+ * @details Get interval (in milliseconds) in which bursts of NAs and
+ *	    ARPs notifications are sent to peers.
  *
- * Returns: zero on success or negative number in case of an error.
+ * @return Zero on success or negative number in case of an error.
  **/
 TEAM_EXPORT
 int team_get_notify_peers_interval(struct team_handle *th, uint32_t *interval)
@@ -1079,14 +1075,13 @@ int team_get_notify_peers_interval(struct team_handle *th, uint32_t *interval)
 }
 
 /**
- * team_set_notify_peers_interval:
- * @th: libteam library context
- * @interval: interval of bursts
+ * @param th		libteam library context
+ * @param interval	interval of bursts
  *
- * Set interval (in milliseconds) in which bursts of NAs and ARPs notifications
- * will be sent to peers.
+ * @details Set interval (in milliseconds) in which bursts of NAs and
+ *	    ARPs notifications will be sent to peers.
  *
- * Returns: zero on success or negative number in case of an error.
+ * @return Zero on success or negative number in case of an error.
  **/
 TEAM_EXPORT
 int team_set_notify_peers_interval(struct team_handle *th, uint32_t interval)
@@ -1100,13 +1095,12 @@ int team_set_notify_peers_interval(struct team_handle *th, uint32_t interval)
 }
 
 /**
- * team_get_mcast_rejoin_count:
- * @th: libteam library context
- * @count: where the count will be stored
+ * @param th		libteam library context
+ * @param count		where the count will be stored
  *
- * Get number of bursts of multicast group rejoins to be sent.
+ * @details Get number of bursts of multicast group rejoins to be sent.
  *
- * Returns: zero on success or negative number in case of an error.
+ * @return Zero on success or negative number in case of an error.
  **/
 TEAM_EXPORT
 int team_get_mcast_rejoin_count(struct team_handle *th, uint32_t *count)
@@ -1121,13 +1115,12 @@ int team_get_mcast_rejoin_count(struct team_handle *th, uint32_t *count)
 }
 
 /**
- * team_set_mcast_rejoin_count:
- * @th: libteam library context
- * @count: number of bursts
+ * @param th		libteam library context
+ * @param count		number of bursts
  *
- * Set number of bursts of multicast group rejoins to be sent.
+ * @details Set number of bursts of multicast group rejoins to be sent.
  *
- * Returns: zero on success or negative number in case of an error.
+ * @return Zero on success or negative number in case of an error.
  **/
 TEAM_EXPORT
 int team_set_mcast_rejoin_count(struct team_handle *th, uint32_t count)
@@ -1141,13 +1134,12 @@ int team_set_mcast_rejoin_count(struct team_handle *th, uint32_t count)
 }
 
 /**
- * team_get_mcast_rejoin_interval:
- * @th: libteam library context
- * @interval: where the interval will be stored
+ * @param th		libteam library context
+ * @param interval:	where the interval will be stored
  *
- * Get interval (in milliseconds) in which bursts of rejoins are sent.
+ * @details Get interval (in milliseconds) in which bursts of rejoins are sent.
  *
- * Returns: zero on success or negative number in case of an error.
+ * @return Zero on success or negative number in case of an error.
  **/
 TEAM_EXPORT
 int team_get_mcast_rejoin_interval(struct team_handle *th, uint32_t *interval)
@@ -1162,13 +1154,12 @@ int team_get_mcast_rejoin_interval(struct team_handle *th, uint32_t *interval)
 }
 
 /**
- * team_set_mcast_rejoin_interval:
- * @th: libteam library context
- * @interval: interval of bursts
+ * @param th		libteam library context
+ * @param interval	interval of bursts
  *
- * Set interval (in milliseconds) in which bursts of rejoins are sent.
+ * @details Set interval (in milliseconds) in which bursts of rejoins are sent.
  *
- * Returns: zero on success or negative number in case of an error.
+ * @return Zero on success or negative number in case of an error.
  **/
 TEAM_EXPORT
 int team_set_mcast_rejoin_interval(struct team_handle *th, uint32_t interval)
@@ -1182,14 +1173,13 @@ int team_set_mcast_rejoin_interval(struct team_handle *th, uint32_t interval)
 }
 
 /**
- * team_get_active_port:
- * @th: libteam library context
- * @ifindex: where the port interface index will be stored
+ * @param th		libteam library context
+ * @param ifindex	where the port interface index will be stored
  *
- * Get interface index of active port. Note this is possible only if
- * team is in "activebackup" mode.
+ * @details Get interface index of active port. Note this is possible only if
+ *	    team is in "activebackup" mode.
  *
- * Returns: zero on success or negative number in case of an error.
+ * @return Zero on success or negative number in case of an error.
  **/
 TEAM_EXPORT
 int team_get_active_port(struct team_handle *th, uint32_t *ifindex)
@@ -1204,14 +1194,13 @@ int team_get_active_port(struct team_handle *th, uint32_t *ifindex)
 }
 
 /**
- * team_set_active_port:
- * @th: libteam library context
- * @ifindex: interface index of new active port
+ * @param th		libteam library context
+ * @param ifindex	interface index of new active port
  *
- * Set new active port by give @ifindex. Note this is possible only if
- * team is in "activebackup" mode.
+ * @details Set new active port by given ifindex. Note this is possible only if
+ *	    team is in "activebackup" mode.
  *
- * Returns: zero on success or negative number in case of an error.
+ * @return Zero on success or negative number in case of an error.
  **/
 TEAM_EXPORT
 int team_set_active_port(struct team_handle *th, uint32_t ifindex)
@@ -1225,14 +1214,13 @@ int team_set_active_port(struct team_handle *th, uint32_t ifindex)
 }
 
 /**
- * team_get_bpf_hash_func:
- * @th: libteam library context
- * @fp: where current BPF instruction set will be stored
+ * @param th		libteam library context
+ * @param fp		where current BPF instruction set will be stored
  *
- * Get tx port selecting hash function. Note this is possible only if
- * team is in "loadbalance" mode.
+ * @details Get tx port selecting hash function. Note this is possible only if
+ *	    team is in "loadbalance" mode.
  *
- * Returns: zero on success or negative number in case of an error.
+ * @return Zero on success or negative number in case of an error.
  **/
 TEAM_EXPORT
 int team_get_bpf_hash_func(struct team_handle *th, struct sock_fprog *fp)
@@ -1254,14 +1242,13 @@ int team_get_bpf_hash_func(struct team_handle *th, struct sock_fprog *fp)
 }
 
 /**
- * team_set_bpf_hash_func:
- * @th: libteam library context
- * @fp: prepared BPF instruction set
+ * @param th		libteam library context
+ * @param fp		prepared BPF instruction set
  *
- * Set tx port selecting hash function. Note this is possible only if
- * team is in "loadbalance" mode. Passing NULL clears current function.
+ * @details Set tx port selecting hash function. Note this is possible only if
+ *	    team is in "loadbalance" mode. Passing NULL clears current function.
  *
- * Returns: zero on success or negative number in case of an error.
+ * @return Zero on success or negative number in case of an error.
  **/
 TEAM_EXPORT
 int team_set_bpf_hash_func(struct team_handle *th, const struct sock_fprog *fp)
@@ -1282,14 +1269,13 @@ int team_set_bpf_hash_func(struct team_handle *th, const struct sock_fprog *fp)
 }
 
 /**
- * team_set_port_enabled:
- * @th: libteam library context
- * @port_ifindex: port interface index
- * @val: boolean value
+ * @param th		libteam library context
+ * @param port_ifindex	port interface index
+ * @param val		boolean value
  *
- * Enables or disable port identified by @port_ifindex
+ * @details Enables or disable port identified by port_ifindex
  *
- * Returns: zero on success or negative number in case of an error.
+ * @return Zero on success or negative number in case of an error.
  **/
 TEAM_EXPORT
 int team_set_port_enabled(struct team_handle *th,
@@ -1304,14 +1290,13 @@ int team_set_port_enabled(struct team_handle *th,
 }
 
 /**
- * team_set_port_user_linkup_enabled:
- * @th: libteam library context
- * @port_ifindex: port interface index
- * @val: boolean value
+ * @param th		libteam library context
+ * @param port_ifindex	port interface index
+ * @param val		boolean value
  *
- * Enables or disable user linkup for port identified by @port_ifindex
+ * @details Enables or disable user linkup for port identified by port_ifindex
  *
- * Returns: zero on success or negative number in case of an error.
+ * @return Zero on success or negative number in case of an error.
  **/
 TEAM_EXPORT
 int team_set_port_user_linkup_enabled(struct team_handle *th,
@@ -1327,14 +1312,13 @@ int team_set_port_user_linkup_enabled(struct team_handle *th,
 }
 
 /**
- * team_get_port_user_linkup:
- * @th: libteam library context
- * @port_ifindex: port interface index
- * @ifindex: where the port user link state will be stored
+ * @param th		libteam library context
+ * @param port_ifindex	port interface index
+ * @param linkup	where the port user link state will be stored
  *
- * Gets user linkup for port identified by @port_ifindex
+ * @details Gets user linkup for port identified by port_ifindex
  *
- * Returns: zero on success or negative number in case of an error.
+ * @return Zero on success or negative number in case of an error.
  **/
 TEAM_EXPORT
 int team_get_port_user_linkup(struct team_handle *th,
@@ -1350,14 +1334,13 @@ int team_get_port_user_linkup(struct team_handle *th,
 }
 
 /**
- * team_set_port_user_linkup:
- * @th: libteam library context
- * @port_ifindex: port interface index
- * @linkup: desired link state
+ * @param th		libteam library context
+ * @param port_ifindex	port interface index
+ * @param linkup	desired link state
  *
- * Sets user linkup for port identified by @port_ifindex
+ * @details Sets user linkup for port identified by port_ifindex
  *
- * Returns: zero on success or negative number in case of an error.
+ * @return Zero on success or negative number in case of an error.
  **/
 TEAM_EXPORT
 int team_set_port_user_linkup(struct team_handle *th,
@@ -1373,14 +1356,13 @@ int team_set_port_user_linkup(struct team_handle *th,
 }
 
 /**
- * team_set_port_queue_id:
- * @th: libteam library context
- * @port_ifindex: port interface index
- * @queue_id: desired queue id
+ * @param th		libteam library context
+ * @param port_ifindex	port interface index
+ * @param queue_id	desired queue id
  *
- * Sets queue id for port identified by @port_ifindex
+ * @details Sets queue id for port identified by port_ifindex
  *
- * Returns: zero on success or negative number in case of an error.
+ * @return Zero on success or negative number in case of an error.
  **/
 TEAM_EXPORT
 int team_set_port_queue_id(struct team_handle *th,
@@ -1396,14 +1378,13 @@ int team_set_port_queue_id(struct team_handle *th,
 }
 
 /**
- * team_get_port_priority:
- * @th: libteam library context
- * @port_ifindex: port interface index
- * @priority: where the port priority will be stored
+ * @param th		libteam library context
+ * @param port_ifindex	port interface index
+ * @param priority	where the port priority will be stored
  *
- * Gets priority for port identified by @port_ifindex
+ * @details Gets priority for port identified by port_ifindex
  *
- * Returns: zero on success or negative number in case of an error.
+ * @return Zero on success or negative number in case of an error.
  **/
 TEAM_EXPORT
 int team_get_port_priority(struct team_handle *th,
@@ -1419,14 +1400,13 @@ int team_get_port_priority(struct team_handle *th,
 }
 
 /**
- * team_set_port_priority:
- * @th: libteam library context
- * @port_ifindex: port interface index
- * @priority: desired priority
+ * @param th		libteam library context
+ * @param port_ifindex	port interface index
+ * @param priority	desired priority
  *
- * Sets priority for port identified by @port_ifindex
+ * @details Sets priority for port identified by port_ifindex
  *
- * Returns: zero on success or negative number in case of an error.
+ * @return Zero on success or negative number in case of an error.
  **/
 TEAM_EXPORT
 int team_set_port_priority(struct team_handle *th,
@@ -1443,17 +1423,15 @@ int team_set_port_priority(struct team_handle *th,
 
 /**
  * SECTION: RTNL helpers
- * @short_description: Route netlink helper function
  */
 
 /**
- * team_ifname2ifindex:
- * @th: libteam library context
- * @ifname: interface name
+ * @param th		libteam library context
+ * @param ifname	interface name
  *
- * Looks up for interface of given name and gets its index.
+ * @details Looks up for interface of given name and gets its index.
  *
- * Returns: zero if interface is not found,
+ * @return Zero if interface is not found,
  *	    interface index as reffered by in kernel otherwise.
  **/
 TEAM_EXPORT
@@ -1472,16 +1450,14 @@ uint32_t team_ifname2ifindex(struct team_handle *th, const char *ifname)
 }
 
 /**
- * team_ifindex2ifname:
- * @th: libteam library context
- * @ifindex: interface index
- * @ifname: where the interface name will be stored
- * @maxlen: length of ifname buffer
+ * @param th		libteam library context
+ * @param ifindex	interface index
+ * @param ifname	where the interface name will be stored
+ * @param maxlen	length of ifname buffer
  *
- * Looks up for interface of given index and gets its name.
+ * @details Looks up for interface of given index and gets its name.
  *
- * Returns: NULL if interface is not found,
- *	    @ifname otherwise.
+ * @return NULL if interface is not found, ifname otherwise.
  **/
 TEAM_EXPORT
 char *team_ifindex2ifname(struct team_handle *th, uint32_t ifindex,
@@ -1499,13 +1475,12 @@ char *team_ifindex2ifname(struct team_handle *th, uint32_t ifindex,
 }
 
 /**
- * team_port_add:
- * @th: libteam library context
- * @port_ifindex: port interface index
+ * @param th		libteam library context
+ * @param port_ifindex	port interface index
  *
- * Adds port into team.
+ * @details Adds port into team.
  *
- * Returns: zero on success or negative number in case of an error.
+ * @return Zero on success or negative number in case of an error.
  **/
 TEAM_EXPORT
 int team_port_add(struct team_handle *th, uint32_t port_ifindex)
@@ -1518,13 +1493,12 @@ int team_port_add(struct team_handle *th, uint32_t port_ifindex)
 }
 
 /**
- * team_our_port_port:
- * @th: libteam library context
- * @port_ifindex: port interface index
+ * @param th		libteam library context
+ * @param port_ifindex	port interface index
  *
- * Find out if interface is port of this team.
+ * @details Find out if interface is port of this team.
  *
- * Returns: true if interface is port of this team.
+ * @return True if interface is port of this team.
  **/
 TEAM_EXPORT
 bool team_is_our_port(struct team_handle *th, uint32_t port_ifindex)
@@ -1542,13 +1516,12 @@ bool team_is_our_port(struct team_handle *th, uint32_t port_ifindex)
 }
 
 /**
- * team_port_remove:
- * @th: libteam library context
- * @port_ifindex: port interface index
+ * @param th		libteam library context
+ * @param port_ifindex	port interface index
  *
- * Removes port from team.
+ * @details Removes port from team.
  *
- * Returns: zero on success or negative number in case of an error.
+ * @return Zero on success or negative number in case of an error.
  **/
 TEAM_EXPORT
 int team_port_remove(struct team_handle *th, uint32_t port_ifindex)
@@ -1560,14 +1533,12 @@ int team_port_remove(struct team_handle *th, uint32_t port_ifindex)
 }
 
 /**
- * team_carrier_set:
- * @th: libteam library context
- * @ifindex: interface index
- * @status: carrier status
+ * @param th		libteam library context
+ * @param carrier_up	carrier state to be set
  *
- * Sets carrier status for the master network interface
+ * @details Sets carrier status for the master network interface
  *
- * Returns: zero on success or negative number in case of an error.
+ * @return Zero on success or negative number in case of an error.
  **/
 TEAM_EXPORT
 int team_carrier_set(struct team_handle *th, bool carrier_up)
@@ -1598,13 +1569,12 @@ int team_carrier_set(struct team_handle *th, bool carrier_up)
 }
 
 /**
- * team_carrier_get:
- * @th: libteam library context
- * @carrier_up: where the carrier state will be stored
+ * @param th		libteam library context
+ * @param carrier_up	where the carrier state will be stored
  *
- * Gets carrier status of the master network interface
+ * @details Gets carrier status of the master network interface
  *
- * Returns: zero on success or negative number in case of an error.
+ * @return Zero on success or negative number in case of an error.
  **/
 TEAM_EXPORT
 int team_carrier_get(struct team_handle *th, bool *carrier_up)
@@ -1629,16 +1599,15 @@ int team_carrier_get(struct team_handle *th, bool *carrier_up)
 }
 
 /**
- * team_hwaddr_set:
- * @th: libteam library context
- * @ifindex: interface index
- * @addr: address to be set
- * @addr_len: length of addr
+ * @param th		libteam library context
+ * @param ifindex	interface index
+ * @param addr		address to be set
+ * @param addr_len	length of addr
  *
- * Sets given hardware address (MAC) for network interface by given
- * interface index.
+ * @details Sets given hardware address (MAC) for network interface by given
+ *	    interface index.
  *
- * Returns: zero on success or negative number in case of an error.
+ * @return Zero on success or negative number in case of an error.
  **/
 TEAM_EXPORT
 int team_hwaddr_set(struct team_handle *th, uint32_t ifindex,
@@ -1672,16 +1641,15 @@ errout:
 }
 
 /**
- * team_hwaddr_get:
- * @th: libteam library context
- * @ifindex: interface index
- * @addr: address will be written here
- * @addr_len: length of addr buffer
+ * @param th		libteam library context
+ * @param ifindex	interface index
+ * @param addr		address will be written here
+ * @param addr_len	length of addr buffer
  *
- * Gets hardware address (MAC) of network interface by given
- * interface index.
+ * @details Gets hardware address (MAC) of network interface by given
+ *	    interface index.
  *
- * Returns: zero on success or negative number in case of an error.
+ * @return Zero on success or negative number in case of an error.
  **/
 TEAM_EXPORT
 int team_hwaddr_get(struct team_handle *th, uint32_t ifindex,
@@ -1713,14 +1681,13 @@ errout:
 }
 
 /**
- * team_hwaddr_len_get:
- * @th: libteam library context
- * @ifindex: interface index
+ * @param th		libteam library context
+ * @param ifindex	interface index
  *
- * Gets length of hardware address (MAC) of network interface by given
- * interface index.
+ * @details Gets length of hardware address (MAC) of network interface by given
+ *	    interface index.
  *
- * Returns: number of bytes on success or negative number in case of an error.
+ * @return Number of bytes on success or negative number in case of an error.
  **/
 TEAM_EXPORT
 int team_hwaddr_len_get(struct team_handle *th, uint32_t ifindex)
@@ -1746,15 +1713,19 @@ errout:
 }
 
 /**
- * team_get_ifinfo:
- * @th: libteam library context
+ * @param th		libteam library context
  *
- * Get team device rtnetlink interface info.
+ * @details Get team device rtnetlink interface info.
  *
- * Returns: pointer to appropriate team_ifinfo structure.
+ * @return Pointer to appropriate team_ifinfo structure.
  **/
 TEAM_EXPORT
 struct team_ifinfo *team_get_ifinfo(struct team_handle *th)
 {
 	return th->ifinfo;
 }
+
+/**
+ * @}
+ * @}
+ */
